# Migrate from 1.15 to 1.17

To upgrade Kyma from 1.15 to 1.17 you have to perform two steps:
1. upgrade to a Release Candidate version of Kyma tagged 1.16.0-rc3,
2. upgrade to an official Release 1.17 version of Kyma
 
 This document contains two sections describing actions you have to perform before or after each step.

## Migrate from 1.15 to 1.16.0-rc3

### Istio

Kyma 1.16.0-rc3 comes with a new Istio version: 1.5.10, which introduces a new custom resource for Istio installation. If you use any overrides provided by Helm or IstioControlPlane, migrate them to the new [IstioOperator](https://istio.io/v1.5/docs/reference/config/istio.operator.v1alpha1/). See [an example of IstioOperator](https://kyma-project.io/docs/1.16/components/service-mesh/#configuration-istio-custom-configuration) for more information.

All Istio-related objects in Kyma are updated, but the migration may be necessary for the Istio objects created manually in your cluster.
Please read the [Istio upgrade notes](https://istio.io/latest/news/releases/1.5.x/announcing-1.5/upgrade-notes/) for the details.
Please ensure you're not using Istio RBAC, which is [deprecated](https://istio.io/v1.5/docs/reference/config/security/istio.rbac.v1alpha1/) and may not work after the upgrade. Use the [Authorization Policy](https://istio.io/latest/docs/reference/config/security/authorization-policy/) to configure authorization for your services.
In addition, consider migrating existing Authentication Policy to equivalent PeerAuthentication and RequestAuthentication objects.

### Eventing

In Release Candidate 1.16.0-rc3, we remove the support for Knative-Serving from Kyma. After the upgrade Knative-Serving is still installed and fully functional in the cluster, but can be removed easily in order to free resources. Removing Knative-Serving will not affect supported Kyma functionality.

Before you remove Knative-Serving from the cluster, make sure that you create a backup of any of your own resources that used Knative-Serving. You can do this by running:

```bash
kubectl get serving -A -oyaml > <backup-file-name>
```

To remove the `knative-serving` chart, execute:

```bash
helm delete knative-serving -n knative-serving
``` 
>**NOTE:** This requires Helm version 3.x

This command renders Knative-Serving inactive, but all user-created configuration is still available in the cluster. 
To remove the CustomResourceDefinitions for Knative-Serving along with the respective CustomResources, run:

```bash
kubectl delete crd \
  certificates.networking.internal.knative.dev \
  configurations.serving.knative.dev \
  images.caching.internal.knative.dev \
  ingresses.networking.internal.knative.dev \
  metrics.autoscaling.internal.knative.dev \
  podautoscalers.autoscaling.internal.knative.dev \
  revisions.serving.knative.dev \
  routes.serving.knative.dev \
  serverlessservices.networking.internal.knative.dev \
  services.serving.knative.dev
```

### Logging

In Release Candidate 1.16.0-rc3, we change the `instance` label on the logs corresponding to the Pod name to `pod`, which fits the observability ecosystem better.
Also, the `container` label for a function pointing to `lambda` in the previous releases now points to `function`. 
If you search for the logs from a function with the `container: lambda` filter, you will need to change it to `container: function` from this release on.

## Migrate from 1.16.0-rc3 to 1.17

### Istio

Kyma 1.17 comes with a new Istio version: 1.7.4. 

>**NOTE:** To upgrade successfully, make sure your cluster runs Kubernetes version 1.16 or higher.

Istio's Authenication Policy is no longer supported. Replace it with Peer Authentication and RequestAuthentication.

Additionally, this Istio version updates the CRD of the Virtual Service. The way to provide cross-origin resource sharing (CORS) configuration changes:

```bash
# Old way
allowOrigin:
  - "*"

# New way
allowOrigins:
  - regex: ".*"
```

To resolve the compability issues, we introduce a migration job which adds a new field to every Virtual Service on the cluster without deleting the previous configuration:

```bash
spec:
  http:
  - match:
    corsPolicy:
      allowOrigins:
        - regex: ".*"
```

After the upgrade, check if you have a custom Allowed Origins CORS configuration in your Virtual Services. You will have to migrate these Virtual Services manually. Run:

```bash
kubectl get vs --all-namespaces -o=go-template --template='{{ range .items }}{{ $name := .metadata.name}}{{ range $key, $value := .spec.http}}{{if $value.corsPolicy.allowOrigin }}{{ printf "%s : " $name }}{{ printf "%v\n" $value.corsPolicy.allowOrigin }}{{println ""}}{{ end }}{{ end }}{{ end }}'
```

The command returns a list of pairs consisting of the Virtual Service name and allowed origins. Look for entries different from `{VS_NAME} : [*]` and migrate them manually to the [new version](https://istio.io/latest/docs/reference/config/networking/virtual-service/#CorsPolicy). You can find the old configuration under the key `spec.http.corsPolicy.allowOrigin`.
